@@ -38,6 +38,8 @@ my $title_image;
 
 # should go to utility module
 sub dir_is_movie($) {
+   return undef; #d# not ready yet
+
    -f "$_[0]/VIDEO_TS/VIDEO_TS.IFO"		and return "dvd";
    -d "$_[0]/BDMV/STREAM"			and return "br";
 
@@ -410,6 +412,12 @@ sub load_image {
                }
             }
 
+            # hack, ffmpeg does not support dvds
+            if ($moviedir && !$w) {
+               ($w, $h) = (1280, 720);
+            }
+
+
          } else {
             no integer;
 
@@ -1008,7 +1016,7 @@ sub handle_key {
       } elsif ($self->{player_pid} && $key == $Gtk2::Gdk::Keysyms{j}) {
          print {$self->{mplayer_fh}} "sub_select\n";
       } elsif ($self->{player_pid} && $key == $Gtk2::Gdk::Keysyms{o}) {
-         print {$self->{mplayer_fh}} "osd\n";
+         print {$self->{mplayer_fh}} "no-osd cycle-values osd-level 2 3 0 1\n";
       } elsif ($self->{player_pid} && $key == $Gtk2::Gdk::Keysyms{p}) {
          print {$self->{mplayer_fh}} "pause\n";
       } elsif ($self->{player_pid} && $key == $Gtk2::Gdk::Keysyms{Escape}) {
