@@ -172,6 +172,10 @@ my %ext_logo = (
    tif  => "tif",
    tiff => "tif",
 
+   webp => "png",
+   wep  => "png",
+   wej  => "jpeg",
+
    mp2  => "mp2",
    mp3  => "mp3",
    m4a  => "audio",
